==> stomp__stompjs-5.0.2.jar: META-INF/resources/webjars/stomp__stompjs/5.0.2/esm5/stomp-handler.d.ts <==
import { Client } from './client';
import { StompConfig } from './stomp-config';
import { StompHeaders } from './stomp-headers';
import { StompSubscription } from './stomp-subscription';
import { Transaction } from './transaction';
import { closeEventCallbackType, debugFnType, frameCallbackType, IPublishParams, messageCallbackType } from './types';
import { Versions } from './versions';
/**
 * The STOMP protocol handler
 *
 * Part of `@stomp/stompjs`.
 *
 * @internal
 */
export declare class StompHandler {
    private _client;
    private _webSocket;
    debug: debugFnType;
    stompVersions: Versions;
    connectHeaders: StompHeaders;
    disconnectHeaders: StompHeaders;
    heartbeatIncoming: number;
    heartbeatOutgoing: number;
    onUnhandledMessage: messageCallbackType;
    onUnhandledReceipt: frameCallbackType;
    onUnhandledFrame: frameCallbackType;
    onConnect: frameCallbackType;
    onDisconnect: frameCallbackType;
    onStompError: frameCallbackType;
    onWebSocketClose: closeEventCallbackType;
    readonly connectedVersion: string;
    private _connectedVersion;
    readonly connected: boolean;
    private _connected;
    private readonly _subscriptions;
    private readonly _receiptWatchers;
    private _partialData;
    private _escapeHeaderValues;
    private _counter;
    private _pinger;
    private _ponger;
    private _lastServerActivityTS;
    constructor(_client: Client, _webSocket: WebSocket, config?: StompConfig);
    configure(conf: StompConfig): void;
    start(): void;
    private readonly _serverFrameHandlers;
    private _setupHeartbeat;
    private _transmit;
    dispose(): void;
    private _cleanUp;
    publish(params: IPublishParams): void;
    watchForReceipt(receiptId: string, callback: frameCallbackType): void;
    subscribe(destination: string, callback: messageCallbackType, headers?: StompHeaders): StompSubscription;
    unsubscribe(id: string, headers?: StompHeaders): void;
    begin(transactionId: string): Transaction;
    commit(transactionId: string): void;
    abort(transactionId: string): void;
    ack(messageId: string, subscriptionId: string, headers?: StompHeaders): void;
    nack(messageId: string, subscriptionId: string, headers?: StompHeaders): void;
}

==> stomp__stompjs-5.1.0.jar: META-INF/resources/webjars/stomp__stompjs/5.1.0/esm5/stomp-handler.d.ts <==
import { Client } from './client';
import { ITransaction } from './i-transaction';
import { StompConfig } from './stomp-config';
import { StompHeaders } from './stomp-headers';
import { StompSubscription } from './stomp-subscription';
import { closeEventCallbackType, debugFnType, frameCallbackType, IPublishParams, messageCallbackType, wsErrorCallbackType } from './types';
import { Versions } from './versions';
/**
 * The STOMP protocol handler
 *
 * Part of `@stomp/stompjs`.
 *
 * @internal
 */
export declare class StompHandler {
    private _client;
    private _webSocket;
    debug: debugFnType;
    stompVersions: Versions;
    connectHeaders: StompHeaders;
    disconnectHeaders: StompHeaders;
    heartbeatIncoming: number;
    heartbeatOutgoing: number;
    onUnhandledMessage: messageCallbackType;
    onUnhandledReceipt: frameCallbackType;
    onUnhandledFrame: frameCallbackType;
    onConnect: frameCallbackType;
    onDisconnect: frameCallbackType;
    onStompError: frameCallbackType;
    onWebSocketClose: closeEventCallbackType;
    onWebSocketError: wsErrorCallbackType;
    logRawCommunication: boolean;
    readonly connectedVersion: string;
    private _connectedVersion;
    readonly connected: boolean;
    private _connected;
    private readonly _subscriptions;
    private readonly _receiptWatchers;
    private _partialData;
    private _escapeHeaderValues;
    private _counter;
    private _pinger;
    private _ponger;
    private _lastServerActivityTS;
    constructor(_client: Client, _webSocket: WebSocket, config?: StompConfig);
    configure(conf: StompConfig): void;
    start(): void;
    private readonly _serverFrameHandlers;
    private _setupHeartbeat;
    private _transmit;
    dispose(): void;
    private _cleanUp;
    publish(params: IPublishParams): void;
    watchForReceipt(receiptId: string, callback: frameCallbackType): void;
    subscribe(destination: string, callback: messageCallbackType, headers?: StompHeaders): StompSubscription;
    unsubscribe(id: string, headers?: StompHeaders): void;
    begin(transactionId: string): ITransaction;
    commit(transactionId: string): void;
    abort(transactionId: string): void;
    ack(messageId: string, subscriptionId: string, headers?: StompHeaders): void;
    nack(messageId: string, subscriptionId: string, headers?: StompHeaders): void;
}
